==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/constants/impl/LiteralSymbolicConstantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.constants.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.constants.LeafSymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.LiteralSymbolicConstant;
import io.ciera.tool.sql.ooaofooa.constants.LiteralSymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.impl.LeafSymbolicConstantSetImpl;

import java.util.Arrays;
import java.util.List;


public class LiteralSymbolicConstantSetImpl extends InstanceSet<LiteralSymbolicConstantSet,LiteralSymbolicConstant> implements LiteralSymbolicConstantSet {

    // attributes
    @Override
    public void setDT_ID_Deprecated( UniqueId m_DT_ID_Deprecated ) throws XtumlException {
        for ( LiteralSymbolicConstant literalsymbolicconstant : this ) literalsymbolicconstant.setDT_ID_Deprecated( m_DT_ID_Deprecated );
    }
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( LiteralSymbolicConstant literalsymbolicconstant : this ) literalsymbolicconstant.setValue( m_Value );
    }
    @Override
    public void setConst_ID( UniqueId ref_Const_ID ) throws XtumlException {
        for ( LiteralSymbolicConstant literalsymbolicconstant : this ) literalsymbolicconstant.setConst_ID( ref_Const_ID );
    }


    // selections
    @Override
    public LeafSymbolicConstantSet R1503_is_a_LeafSymbolicConstant() throws XtumlException {
        LeafSymbolicConstantSet leafsymbolicconstantset = new LeafSymbolicConstantSetImpl();
        for ( LiteralSymbolicConstant literalsymbolicconstant : this ) leafsymbolicconstantset.add( literalsymbolicconstant.R1503_is_a_LeafSymbolicConstant() );
        return leafsymbolicconstantset;
    }


    @Override
    public LiteralSymbolicConstant nullElement() {
        return LiteralSymbolicConstantImpl.EMPTY_LITERALSYMBOLICCONSTANT;
    }

    @Override
    public LiteralSymbolicConstantSet emptySet() {
      return new LiteralSymbolicConstantSetImpl();
    }

    @Override
    public LiteralSymbolicConstantSet value() {
        return this;
    }

    @Override
    public List<LiteralSymbolicConstant> elements() {
        return Arrays.asList(toArray(new LiteralSymbolicConstant[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/constants/impl/LiteralSymbolicConstantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.constants.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.constants.LeafSymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.LiteralSymbolicConstant;
import io.ciera.tool.sql.ooaofooa.constants.LiteralSymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.impl.LeafSymbolicConstantSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class LiteralSymbolicConstantSetImpl extends InstanceSet<LiteralSymbolicConstantSet,LiteralSymbolicConstant> implements LiteralSymbolicConstantSet {

    public LiteralSymbolicConstantSetImpl() {
    }

    public LiteralSymbolicConstantSetImpl(Comparator<? super LiteralSymbolicConstant> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setConst_ID( UniqueId ref_Const_ID ) throws XtumlException {
        for ( LiteralSymbolicConstant literalsymbolicconstant : this ) literalsymbolicconstant.setConst_ID( ref_Const_ID );
    }
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( LiteralSymbolicConstant literalsymbolicconstant : this ) literalsymbolicconstant.setValue( m_Value );
    }
    @Override
    public void setDT_ID_Deprecated( UniqueId m_DT_ID_Deprecated ) throws XtumlException {
        for ( LiteralSymbolicConstant literalsymbolicconstant : this ) literalsymbolicconstant.setDT_ID_Deprecated( m_DT_ID_Deprecated );
    }


    // selections
    @Override
    public LeafSymbolicConstantSet R1503_is_a_LeafSymbolicConstant() throws XtumlException {
        LeafSymbolicConstantSet leafsymbolicconstantset = new LeafSymbolicConstantSetImpl();
        for ( LiteralSymbolicConstant literalsymbolicconstant : this ) leafsymbolicconstantset.add( literalsymbolicconstant.R1503_is_a_LeafSymbolicConstant() );
        return leafsymbolicconstantset;
    }


    @Override
    public LiteralSymbolicConstant nullElement() {
        return LiteralSymbolicConstantImpl.EMPTY_LITERALSYMBOLICCONSTANT;
    }

    @Override
    public LiteralSymbolicConstantSet emptySet() {
      return new LiteralSymbolicConstantSetImpl();
    }

    @Override
    public LiteralSymbolicConstantSet emptySet(Comparator<? super LiteralSymbolicConstant> comp) {
      return new LiteralSymbolicConstantSetImpl(comp);
    }

    @Override
    public LiteralSymbolicConstantSet value() {
        return this;
    }

    @Override
    public List<LiteralSymbolicConstant> elements() {
        return Arrays.asList(toArray(new LiteralSymbolicConstant[0]));
    }

}
